@@ -30,7 +30,12 @@
 #include <errno.h>
 #include "getopt.h"
 
+#include "config.h"
+#ifdef ENABLE_NLS
+#include <locale.h>
+#endif
 #include "librio500.h"
+#include "i18n.h"
 
 #ifndef TRUE
 
@@ -39,18 +44,11 @@
 
 #endif /* TRUE */
 
-#define STR_RIFF (((((('R' << 8) | 'I') << 8) | 'F') << 8) | 'F')
-#define STR_WAVE (((((('W' << 8) | 'A') << 8) | 'V') << 8) | 'E')
-#define STR_MPEG (((((('M' << 8) | 'P') << 8) | 'E') << 8) | 'G')
-#define STR_fmt  (((((('f' << 8) | 'm') << 8) | 't') << 8) | ' ')
-#define STR_fact (((((('f' << 8) | 'a') << 8) | 'c') << 8) | 't')
-#define STR_data (((((('d' << 8) | 'a') << 8) | 't') << 8) | 'a')
-
 void  usage (char *progname);
 #ifndef WITH_USBDEVFS
 int   write_song (int rio_dev, char *filename, int card_number);
 #else
-int   write_song (struct usbdevice *rio_dev, char *filename, int card_number);
+int   write_song (struct usb_dev_handle *rio_dev, char *filename, int card_number);
 #endif
 int   file_size (char *filename);
 char *strip_path (char *f);
@@ -63,10 +61,7 @@ void
 get_some_switches (int argc, char *argv[], int *font_number, int *folder_num, int *card_number, int *card_auto);
 GList *add_song_to_list (GList *songs, char *filename, int offset, char *font_name, int font_number);
 #endif
-static unsigned long get_frame_header(FILE *fp);
-static int is_frame_header(unsigned long fh);
-static int mp3_read_long(unsigned long *fhp, FILE *fp);
-static int mp3_read_byte(unsigned long *fhp, FILE *fp);
+extern unsigned long get_frame_header(FILE *fp);
 
 char *font_name = DEFAULT_FONT_PATH;
 char *temp_name;
@@ -129,11 +124,11 @@ char     *strip_tailspace(char *string);
 void
 usage (char *progname)
 {
-  printf ("\nusage: %s [OPTIONS] <file1.mp3> . . . <fileN.mp3>\n", progname);
-  printf ("\n [OPTIONS]  Try --help for more information");
-  printf ("\n <fileN.mp3> is the name of the file whose content");
-  printf ("\n we want to upload.  Adding multiple songs is now");
-  printf ("\n supported.");
+  printf (_("\nusage: %s [OPTIONS] <file1.mp3> . . . <fileN.mp3>\n"), progname);
+  printf (_("\n [OPTIONS]  Try --help for more information"));
+  printf (_("\n <fileN.mp3> is the name of the file whose content"));
+  printf (_("\n we want to upload.  Adding multiple songs is now"));
+  printf (_("\n supported."));
   printf("\n\n");
 return;
 }
@@ -146,7 +141,6 @@ main(int argc, char *argv[])
   int               folder_num, font_number, card_number, card_auto;
   int 		    mem_left,filesize,card_changed;
   GList            *folders, *songs;
-  mem_status       *mem;
   folder_entry     *f_entry;
   char             *filename;
 #ifdef USE_ID3_TAGS
@@ -156,11 +150,19 @@ main(int argc, char *argv[])
 #ifndef WITH_USBDEVFS
   int              rio_dev;
 #else
-  struct usbdevice   *rio_dev;
-
-  rio_dev = malloc(sizeof(struct usbdevice));
+  struct usb_dev_handle   *rio_dev;
 #endif
 
+#ifdef ENABLE_NLS
+  setlocale (LC_MESSAGES, "");
+  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  textdomain (PACKAGE);
+#endif
+
+/* #ifdef WITH_USBDEVFS
+  rio_dev = malloc(sizeof(struct usbdevice));
+#endif */
+
   /* set defaults, can be overridden with switches*/
   /* Tomoaki . . set the default value for display here (%7,%9) */
 
@@ -181,7 +183,7 @@ main(int argc, char *argv[])
 
   /* quick fix (by Tomoaki) */
   if (optind == argc) {
-      printf ("\nAt least, one mp3 file must be specified! \n\n");
+      printf (_("\nAt least, one mp3 file must be specified! \n\n"));
       exit (-1);
   }
   
@@ -199,8 +201,7 @@ main(int argc, char *argv[])
   rio_dev = open (DEFAULT_DEV_PATH, O_RDWR);
   if (rio_dev < 0)
     {
-      printf ("\nVerify that the rio module is loadad and your Rio is \n");
-      printf ("connected and powered up.\n\n");
+      perror (_("\nVerify that the rio module is loaded and your Rio is\nconnected and powered up "));
       exit (-1);
     }
 
@@ -208,7 +209,7 @@ main(int argc, char *argv[])
    init_communication (rio_dev);
 #else
    if(!(rio_dev = init_communication())) {
-     printf("init_communication() failed!\n");
+     printf(_("init_communication() failed!\n"));
      free(rio_dev);
      return -1;
    }
@@ -232,10 +233,10 @@ main(int argc, char *argv[])
    }
      filesize = file_size(filename);
      if (filesize > mem_left && card_auto && card_number==0) {
-        printf("\nNot enough room in internal memory\n");
-	printf("Autofill has been set\n");
-	printf("Trying external smartmedia card\n");
-	printf("Setting folder number = 0 on external card\n");
+        printf(_("\nNot enough room in internal memory\n"));
+	printf(_("Autofill has been set\n"));
+	printf(_("Trying external smartmedia card\n"));
+	printf(_("Setting folder number = 0 on external card\n"));
 	folder_num = 0;	
 	card_number++;
 	card_changed = 1;
@@ -243,7 +244,7 @@ main(int argc, char *argv[])
      }
    if (filesize > mem_left)
    {
-      printf ("Not enough space left in rio for %s.\n",filename);
+      printf (_("Not enough space left in rio for %s.\n"),filename);
       goto try_next;
       finish_communication (rio_dev);
       exit (0);
@@ -256,10 +257,10 @@ main(int argc, char *argv[])
 
    if (g_list_length(folders) == 0) {
 	if (card_number == 1) {
-        printf("At least one folder must be created on the smartmedia card before adding songs\n");
+        printf(_("At least one folder must be created on the smartmedia card before adding songs\n"));
 	}
 	else {
-	printf("At least one folder must be created in internal memory before adding songs\n");
+	printf(_("At least one folder must be created in internal memory before adding songs\n"));
         }
 	finish_communication (rio_dev);
 	exit(0);
@@ -280,7 +281,7 @@ main(int argc, char *argv[])
    if (songs == NULL)
    {
      fprintf (stderr, 
-        "Couldn't upload file. No more song entries or incorrect filename.\n");
+        _("Couldn't upload file. No more song entries or incorrect filename.\n"));
      finish_communication (rio_dev);
 #ifndef WITH_USBDEVFS
      close (rio_dev);
@@ -362,7 +363,9 @@ add_song_to_list (GList *songs, char *filename, int offset, char *font_name, int
   char                *striped_name;
   song_entry          *entry;
 #ifdef USE_ID3_TAGS
+  /*
   char                *display_string;
+  */
 #endif
   
   fp = fopen (filename, "r");
@@ -376,7 +379,9 @@ add_song_to_list (GList *songs, char *filename, int offset, char *font_name, int
   entry->offset = (WORD)  offset;
   entry->length = (DWORD) size;
   entry->dunno3 = (WORD) 0x0020;
+#ifdef USE_ID3_TAGS
   entry->mp3sig = (DWORD) get_frame_header(fp);
+#endif
   entry->time   = (DWORD) time (NULL);
   fclose (fp);
 
@@ -409,99 +414,6 @@ add_song_to_list (GList *songs, char *filename, int offset, char *font_name, int
   return g_list_first (new_entry);
 }
 
-static unsigned long
-get_frame_header(FILE *fp)
-{
-	unsigned long fh = 0;
-	int i;
-
-	if (!mp3_read_long(&fh, fp)) 
-		return 0;
-	if (fh == STR_RIFF) {
-riff:		if (!mp3_read_long(&fh, fp)) 
-			return 0;
-		if (!mp3_read_long(&fh, fp)) 
-			return 0;
-		if (fh != STR_MPEG) {
-			if (fh != STR_WAVE) {
-				goto search;
-			}
-			if (!mp3_read_long(&fh, fp)) 
-				return 0;
-			if (fh != STR_fmt) {
-				goto search;
-			}
-			if (!mp3_read_long(&fh, fp)) 
-				return 0;
-			if (fh > 4096) {
-				goto search;
-			}
-			for (i = fh; i--; ) 
-				if (getc(fp) == EOF) 
-					return 0;
-		}
-		if (!mp3_read_long(&fh, fp)) 
-			return 0;
-		if (fh == STR_fact) {
-			if (!mp3_read_long(&fh, fp)) 
-				return 0;
-			if (fh > 4096) {
-				goto search;
-			}
-			for (i = fh; i--; ) 
-				if (getc(fp) == EOF) 
-					return 0;
-			if (!mp3_read_long(&fh, fp)) 
-				return 0;
-		}
-		if (fh != STR_data) {
-			goto search;
-		}
-		if (!mp3_read_long(&fh, fp)) 
-			return 0;
-		if (!mp3_read_long(&fh, fp)) 
-			return 0;
-	}
-
-search:	i = 65536;
-	while (!is_frame_header(fh)) {
-		if (fh == STR_RIFF) 
-			goto riff;
-		if (i-- == 0 || !mp3_read_byte(&fh, fp)) 
-			return 0;
-	}
-	return GUINT32_SWAP_LE_BE(fh);
-}
-
-static int
-is_frame_header(unsigned long fh)
-{
-	return
-		(fh & 0xffe00000) == 0xffe00000 &&
-		((fh >> 17) & 3) != 0 &&
-		((fh >> 12) & 0xf) != 0xf &&
-		((fh >> 10) & 0x3) != 0x3 &&
-		(fh & 0xffff0000) != 0xfffe0000;
-}
-
-static int
-mp3_read_long(unsigned long *fhp, FILE *fp)
-{
-	return
-		mp3_read_byte(fhp, fp) && mp3_read_byte(fhp, fp) &&
-		mp3_read_byte(fhp, fp) && mp3_read_byte(fhp, fp);
-}
-
-static int
-mp3_read_byte(unsigned long *fhp, FILE *fp)
-{
-	int n = getc(fp);
-
-	if (n == EOF) return FALSE;
-	*fhp = (*fhp << 8) | n;
-	return TRUE;
-}
-
 #ifdef USE_ID3_TAGS
 #define GET_ID3TAG( _TAGNAME )                                            \
   _TAGNAME = (char *) calloc( sizeof(id3tag_v1->_TAGNAME) +1, 1);         \
@@ -679,7 +591,7 @@ int
 #ifndef WITH_USBDEVFS
 write_song (int rio_dev, char *filename, int card)
 #else
-write_song (struct usbdevice *rio_dev, char *filename, int card)
+write_song (struct usb_dev_handle *rio_dev, char *filename, int card)
 #endif
 {
   int input_file;
@@ -700,7 +612,7 @@ write_song (struct usbdevice *rio_dev, char *filename, int card)
   num_blocks = size / 0x10000;
   remainder  = size % 0x10000;
 
-  printf ("Transfering file: %s  ", filename);
+  printf (_("Transfering file: %s  "), filename);
   fflush (stdout);
 
   /* First send num_chunks, blocks at a time */
@@ -772,7 +684,7 @@ write_song (struct usbdevice *rio_dev, char *filename, int card)
   send_command (rio_dev, 0x42, 0, 0);
   send_command (rio_dev, 0x42, 0, 0);
   song_location = send_command (rio_dev, 0x43, 0, 0);
-  printf (" (done. Transfered %d bytes.)\n", total);
+  printf (_(" (done. Transfered %d bytes.)\n"), total);
   fflush (stdout);
 
 #ifdef DEBUG
@@ -847,33 +759,33 @@ static struct option const longopts[] =
 
 static char const *const option_help[] =
 {
-"Input options:",
+N_("Input options:"),
 "",
 #ifdef USE_ID3_TAGS
-"  -d %x.%y  --display %x.%y    set Rio500 display's FORMAT like xmms's title.",
-"                               acceptable special characters are below:",
+N_("  -d %x.%y  --display %x.%y    set Rio500 display's FORMAT like xmms's title."),
+N_("                               acceptable special characters are below:"),
 "",
-"                               %1=ID3 Artist  %2=ID3 Title    %3=ID3 Album",
-"                               %4=ID3 Year    %5=ID3 Comment  %6=ID3 Genre",
-"                               %7=File Name   %8=File Path    %9=File Extension",
-"                               %0=Track Number (id3v1.1)",
+N_("                               %1=ID3 Artist  %2=ID3 Title    %3=ID3 Album"),
+N_("                               %4=ID3 Year    %5=ID3 Comment  %6=ID3 Genre"),
+N_("                               %7=File Name   %8=File Path    %9=File Extension"),
+N_("                               %0=Track Number (id3v1.1)"),
 "",
-"                               default FORMAT is %7.%9",
+N_("                               default FORMAT is %7.%9"),
 "",
 #endif
-"  -x        --external         Write to external memory card",
-"  -a        --autofill         Use external memory card if internal full",
-"  -F x      --folder x         Transfer song(s) into folder of index=x",
-"  -f name   --fontname name    Set the fontname to be used on the Rio display.",
-"  -n x      --fontnumber x     Set the fontnumber within the given ",
-"                               .fon file set with -f",
+N_("  -x        --external         Write to external memory card"),
+N_("  -a        --autofill         Use external memory card if internal full"),
+N_("  -F x      --folder x         Transfer song(s) into folder of index=x"),
+N_("  -f name   --fontname name    Set the fontname to be used on the Rio display."),
+N_("  -n x      --fontnumber x     Set the fontnumber within the given "),
+N_("                               .fon file set with -f"),
 "",
-"Miscellaneous options:",
+N_("Miscellaneous options:"),
 "",
-"  -v  --version     Output version info.",
-"  -h  --help        Output this help.",
+N_("  -v        --version          Output version info."),
+N_("  -h        --help             Output this help."),
 "",
-"Report bugs to <rio500-devel@lists.sourceforge.net>.",
+N_("Report bugs to <rio500-devel@lists.sourceforge.net>."),
 0
 };
 
@@ -903,7 +815,7 @@ get_some_switches (int argc, char *argv[], int *font_number, int *folder_num, in
             case 'd':
 		/* Tomoaki - process display switch here */                
                 if (strlen(optarg) >= DISPLAY_FORMAT_LEN) {
-                   fprintf(stderr,"\nID3 format length is too long!\n");
+                   fprintf(stderr,_("\nID3 format length is too long!\n"));
                    usage(argv[0]);
                    exit(-1);
                    break;
@@ -924,7 +836,7 @@ get_some_switches (int argc, char *argv[], int *font_number, int *folder_num, in
 	    case 'F':
 		/* Sanity check --foldernumber digit */
 		if(!isdigit(*optarg)) {
-		   fprintf(stderr,"\nFolder number must be numeric!\n");
+		   fprintf(stderr,_("\nFolder number must be numeric!\n"));
 		   usage(argv[0]);
 		   exit(-1);
 		   break;
@@ -940,7 +852,7 @@ get_some_switches (int argc, char *argv[], int *font_number, int *folder_num, in
 		font_name=temp_name;
                 if ( ( fptemp = fopen(font_name, "rb" ) ) == 0 )
    		{
-                 fprintf(stderr,"\n%s is an invalid fontpath/fontname\n",font_name);
+                 fprintf(stderr,_("\n%s is an invalid fontpath/fontname\n"),font_name);
       	       	 exit(-1);
    		 break;
                 }
@@ -953,7 +865,7 @@ get_some_switches (int argc, char *argv[], int *font_number, int *folder_num, in
             case 'n':
                 /* Sanity check --fontnumber digit */
 		if(!isdigit(*optarg)) {
-		   fprintf(stderr,"\nFont number must be numeric!\n");
+		   fprintf(stderr,_("\nFont number must be numeric!\n"));
 		   usage(argv[0]);
 		   exit(-1);
 		   break;
@@ -961,13 +873,13 @@ get_some_switches (int argc, char *argv[], int *font_number, int *folder_num, in
 		*font_number = atoi(optarg);
 		break;
             case 'v':
-                printf("\nrio_add_song -- version %s\n",VERSION);
+                printf(_("\nrio_add_song -- version %s\n"),VERSION);
 		exit(0);
 		break;
             case 'h':
                 usage(argv[0]);
 		for (p=option_help;  *p ;  p++)
-    	          fprintf (stderr, "%s\n", *p);
+    	          fprintf (stderr, "%s\n", **p ? gettext(*p) : *p);
 		exit(0);
 		break;
             default:
