@@ -26,9 +26,15 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
-#include "getopt.h"
+#include <string.h>
 
+#include "getopt.h"
+#include "config.h"
+#ifdef ENABLE_NLS
+#include <locale.h>
+#endif
 #include "librio500.h"
+#include "i18n.h"
 
 
 #ifndef TRUE
@@ -55,18 +61,18 @@ void get_some_switches (int argc, char *argv[], int *folder_num, int *automat, i
 int remove_folder (int rio_dev, int folder_num, int card_number);
 int remove_song (int rio_dev, int song_num, int folder_num, int card_number);
 #else
-int remove_folder (struct usbdevice *rio_dev, int folder_num, int card_number);
-int remove_song (struct usbdevice *rio_dev, int song_num, int folder_num, int card_number);
+int remove_folder (struct usb_dev_handle *rio_dev, int folder_num, int card_number);
+int remove_song (struct usb_dev_handle *rio_dev, int song_num, int folder_num, int card_number);
 #endif
 
 
 void
 usage (char *progname)
 {
-  printf ("\nusage: %s [OPTIONS] <folder/song1> . . . <folder/songN>\n", progname);
-  printf ("\n [OPTIONS] Try --help for more information\n");
-  printf ("\n <folder/songN> is the index or name of the folder/song you");
-  printf ("\n want to erase.");
+  printf (_("\nusage: %s [OPTIONS] <folder/song1> . . . <folder/songN>\n"), progname);
+  printf (_("\n [OPTIONS] Try --help for more information\n"));
+  printf (_("\n <folder/songN> is the index or name of the folder/song you"));
+  printf (_("\n want to erase."));
   printf ("\n\n");
   return;
 }
@@ -91,18 +97,27 @@ main(int argc, char *argv[])
 #ifndef WITH_USBDEVFS
   int               rio_dev;
 #else
-  struct usbdevice *rio_dev;
-  rio_dev = malloc(sizeof(struct usbdevice));
+  struct usb_dev_handle *rio_dev;
 #endif
 
+#ifdef ENABLE_NLS
+  setlocale (LC_MESSAGES, "");
+  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  textdomain (PACKAGE);
+#endif
+
+/* #ifdef WITH_USBDEVFS
+  rio_dev = malloc(sizeof(struct usbdevice));
+#endif */
+
 /* Some quick checking before we process switches */
 
   if (argc < 2)
   {
     usage (argv[0]);
-#ifdef WITH_USBDEVFS
+/* #ifdef WITH_USBDEVFS
     free(rio_dev);
-#endif
+#endif */
     exit (-1);
   }
 
@@ -118,8 +133,7 @@ main(int argc, char *argv[])
   rio_dev = open (DEFAULT_DEV_PATH, O_RDWR);
   if (rio_dev < 0)
     {
-      printf ("\nVerify that the rio500.o module is loaded, and your Rio is \n");
-      printf ("connected and powered up.\n\n");
+      perror (_("\nVerify that the rio module is loaded and your Rio is\nconnected and powered up "));
       exit (-1);
     }
 
@@ -146,10 +160,10 @@ main(int argc, char *argv[])
 
   if (g_list_length(rio_folders) == 0)
   {
-  	printf("\nReading the folder list from the Rio500 failed\n");
-	printf("Make sure your rio has folders/songs to delete and\n");
-        printf ("verify that the rio500.o module is loaded, and your Rio is \n");
-        printf ("connected and powered up.\n\n");
+  	printf(_("\nReading the folder list from the Rio500 failed\n"));
+	printf(_("Make sure your rio has folders/songs to delete and\n"));
+        printf (_("verify that the rio500.o module is loaded, and your Rio is \n"));
+        printf (_("connected and powered up.\n\n"));
 
 	   finish_communication (rio_dev);
 	#ifndef WITH_USBDEVFS
@@ -194,8 +208,8 @@ main(int argc, char *argv[])
    /* If no matches of foldername<->folderindex then errormsg and exit */
       if (match_flag == 0)
       {
-        printf("\n%s did not match any folder stored on the rio500\n",folder_num_string);
-        printf("Check the folder names and try again\n");
+        printf(_("\n%s did not match any folder stored on the rio500\n"),folder_num_string);
+        printf(_("Check the folder names and try again\n"));
         exit(-1);
       }
 
@@ -204,7 +218,7 @@ main(int argc, char *argv[])
   /* Make sure folder_num isn't set to something stupid with -F */
   if (folder_num < 0 || folder_num>256) /* new limit is 256 folders */
   {
-    printf ("Non-existent folder\n");
+    printf (_("Non-existent folder\n"));
     usage (argv[0]);
     exit (-1);
   }
@@ -212,7 +226,7 @@ main(int argc, char *argv[])
   /* Sanity check -- make sure there is a file to delete */
   if (optind == argc)
   {
-	printf("\nNeed to specify a file name/index to delete\n");
+	printf(_("\nNeed to specify a file name/index to delete\n"));
 	usage(argv[0]);
 	exit(-1);
   }
@@ -248,8 +262,8 @@ main(int argc, char *argv[])
       /* end of match loop, check that a match was found */
       if (match_flag == 0)
       {
-  	printf("\n%s did not match any folder stored on the rio500\n",(char*)arg_ent->data);
-	printf("Check the folder names and try again\n");
+  	printf(_("\n%s did not match any folder stored on the rio500\n"),(char*)arg_ent->data);
+	printf(_("Check the folder names and try again\n"));
 	exit(-1);
       }
     }
@@ -278,8 +292,8 @@ main(int argc, char *argv[])
       /* end of match loop, check that a match was found */
       if (match_flag == 0)
       {
-        printf("\n%s did not match any song stored on the rio500\n",(char*)arg_ent->data);
-        printf("Check the folder names and try again\n");
+        printf(_("\n%s did not match any song stored on the rio500\n"),(char*)arg_ent->data);
+        printf(_("Check the folder names and try again\n"));
         exit(-1);
 
       }
@@ -305,14 +319,14 @@ main(int argc, char *argv[])
 	/* sanity check -- make sure folder num, song num exist on rio */
 	if ((whole_folder == 1) && (folder_num >= folder_list_length))
 	{
-	  printf("\nYou are attempting to delete a non-existent folder index");
-	  printf("\nCheck the folder index number and try again\n");
+	  printf(_("\nYou are attempting to delete a non-existent folder index"));
+	  printf(_("\nCheck the folder index number and try again\n"));
 	  exit(-1);
 	}
 	if ((whole_folder == 0) && (song_num >= g_list_length(song_lists[folder_num])))
 	{
-          printf("\nYou are attempting to delete a non-existent song index");
-	  printf("\nCheck the song index number and try again\n");
+          printf(_("\nYou are attempting to delete a non-existent song index"));
+	  printf(_("\nCheck the song index number and try again\n"));
 	  exit(-1);
         }
 /* Open connection to rio */
@@ -320,8 +334,7 @@ main(int argc, char *argv[])
   rio_dev = open (DEFAULT_DEV_PATH, O_RDWR);
   if (rio_dev < 0)
     {
-      printf ("\nVerify that the rio500.o module is loaded, and your Rio is \n");
-      printf ("connected and powered up.\n\n");
+      perror (_("\nVerify that the rio module is loaded and your Rio is\nconnected and powered up "));
       exit (-1);
     }
 
@@ -330,7 +343,7 @@ main(int argc, char *argv[])
 #else
 
    if(!(rio_dev = init_communication())) {
-     printf("init_communication() failed!\n");
+     printf(_("init_communication() failed!\n"));
      free(rio_dev);
      return -1;
    }
@@ -343,9 +356,9 @@ main(int argc, char *argv[])
      if (!automatic)
        {
 	folder_ent = (folder_entry *) g_list_nth(rio_folders,folder_num)->data; 
-	printf ("Are you sure you want to remove folder <%s>? Type <yes> to confirm. ",(char *)folder_ent->name1);
+	printf (_("Are you sure you want to remove folder <%s>? Type <yes> to confirm. "),(char *)folder_ent->name1);
 	 scanf ( "%s", answer );
-	 if ( strcmp (answer, "yes") != 0 )
+	 if (( strcmp (answer, "yes") != 0 ) && ( strcmp (answer, _("yes")) != 0 ))
 	   {
 	     finish_communication (rio_dev);
 #ifndef WITH_USBDEVFS
@@ -361,9 +374,9 @@ main(int argc, char *argv[])
      if (!automatic)
        {
 	song_ent=(song_entry *) g_list_nth(song_lists[folder_num],song_num)->data; 
-	printf ("Are you sure you want to remove song <%s>? Type <yes> to confirm. ",(char *)song_ent->name1);
+	printf (_("Are you sure you want to remove song <%s>? Type <yes> to confirm. "),(char *)song_ent->name1);
          scanf ( "%s", answer );
-         if ( strcmp (answer, "yes") != 0 )
+         if (( strcmp (answer, "yes") != 0 ) &&  ( strcmp (answer, _("yes")) != 0 ))
            {
              finish_communication (rio_dev);
 #ifndef WITH_USBDEVFS
@@ -391,7 +404,7 @@ int
 #ifndef WITH_USBDEVFS
 remove_folder (int rio_dev, int folder_num, int card_number)
 #else
-remove_folder (struct usbdevice *rio_dev, int folder_num, int card_number)
+remove_folder (struct usb_dev_handle *rio_dev, int folder_num, int card_number)
 #endif
 {
   folder_entry     *folder;
@@ -400,22 +413,30 @@ remove_folder (struct usbdevice *rio_dev, int folder_num, int card_number)
 
   /* Read folder & song block */
   folders = read_folder_entries (rio_dev,card_number);
+  folder  = (folder_entry *)g_list_nth_data (g_list_first(folders), folder_num);
+  if (folder == NULL)
+     return 0;
+
+  /* Is this the last folder? . . just format */
+  if (g_list_length(folders) == 1) {
+    printf (_("Removing folder <%s>...\n"), folder->name1);
+    printf (_("Last folder...formatting\n"));
+    folders = g_list_remove (folders, (gpointer) folder);
+    format_flash(rio_dev,card_number);
+    return 0;
+  }	 
   if ( folder_num > g_list_length (folders)-1 )
     return -1;
   else
     songs   = read_song_entries (rio_dev, folders, folder_num, card_number); 
 
 
-  folder  = (folder_entry *)g_list_nth_data (g_list_first(folders), folder_num);
-  if (folder == NULL)
-     return 0;
-  printf ("Removing folder <%s>...\n", folder->name1);
+  printf (_("Removing folder <%s>...\n"), folder->name1);
 
   for (song_num = g_list_length (songs) - 1; song_num >= 0; song_num--)
     remove_song (rio_dev, song_num, folder_num, card_number);
 
   folders = g_list_remove (folders, (gpointer) folder);
-
   send_command (rio_dev, 0x4c, ((folder_num << 8) | 0xff), card_number);
   write_folder_entries (rio_dev, folders,card_number);
   send_command (rio_dev, 0x42, 0, 0);
@@ -438,7 +459,7 @@ remove_folder (struct usbdevice *rio_dev, int folder_num, int card_number)
 #ifndef WITH_USBDEVFS
 int remove_song (int rio_dev, int song_num, int folder_num,int card_number)
 #else
-int remove_song (struct usbdevice *rio_dev, int song_num, int folder_num, int card_number)
+int remove_song (struct usb_dev_handle *rio_dev, int song_num, int folder_num, int card_number)
 #endif
 {
   song_entry       *song;
@@ -462,7 +483,7 @@ int remove_song (struct usbdevice *rio_dev, int song_num, int folder_num, int ca
    song = (song_entry *) g_list_nth_data (songs, song_num);
    if (song == NULL)
      return 0;
-   printf ("Removing file <%s>...\n", song->name1);
+   printf (_("Removing file <%s>...\n"), song->name1);
 
    songs = g_list_remove (songs, (gpointer)song);
 
@@ -518,23 +539,23 @@ static struct option const longopts[] =
 
 static char const *const option_help[] =
 {
-"Input options:",
+N_("Input options:"),
 "",
-"  -F x      --folder x         Delete song(s) from folder of index x",
-"  -x        --external         Delete from external memory card",
-"  -a        --automatic        Deletes without prompting",
-"  -w        --wholefolder      Treats arguments as folder names/indices",
-"                               Will delete entire folder at once",
-"  -b        --byname           Use folder/song names instead of indicies",
-"                               Names should be names as shown on the",
-"				Rio500", 
+N_("  -F x      --folder x         Delete song(s) from folder of index x"),
+N_("  -x        --external         Delete from external memory card"),
+N_("  -a        --automatic        Deletes without prompting"),
+N_("  -w        --wholefolder      Treats arguments as folder names/indices"),
+N_("                               Will delete entire folder at once"),
+N_("  -b        --byname           Use folder/song names instead of indicies"),
+N_("                               Names should be names as shown on the"),
+N_("                               Rio500"), 
 "",
-"Miscellaneous options:",
+N_("Miscellaneous options:"),
 "",
-"  -v        --version          Output version info.",
-"  -h        --help             Output this help.",
+N_("  -v        --version          Output version info."),
+N_("  -h        --help             Output this help."),
 "",
-"Report bugs to <rio500-devel@lists.sourceforge.net>.",
+N_("Report bugs to <rio500-devel@lists.sourceforge.net>."),
 0
 };
 
@@ -546,7 +567,6 @@ get_some_switches (int argc, char *argv[], int *folder_num, int *automat, int *c
 {
     register int optc;
     char const * const *p;
-    FILE *fptemp=0;
 
     if (optind == argc)
         return;
@@ -572,13 +592,13 @@ get_some_switches (int argc, char *argv[], int *folder_num, int *automat, int *c
 		whole_folder = 1;
 		break;
             case 'v':
-                printf("\nrio_del_song -- version %s\n",VERSION);
+                printf(_("\nrio_del_song -- version %s\n"),VERSION);
                 exit(0);
                 break;
             case 'h':
                 usage(argv[0]);
                 for (p=option_help;  *p ;  p++)
-                  fprintf (stderr, "%s\n", *p);
+                  fprintf (stderr, "%s\n", **p ? gettext(*p) : *p);
                 exit(0);
                 break;
             default:    
