@@ -28,8 +28,15 @@
 #endif
 #include <sys/types.h>
 #include <sys/stat.h>
+
+#include "config.h"
+#ifdef ENABLE_NLS
+#include <locale.h>
+#endif
 #include "libfon.h"
 #include "getopt.h"
+#include "i18n.h"
+
 void get_some_switches (int argc, char *argv[]);
 
 static char infile[512];
@@ -40,6 +47,12 @@ int main( int argc, char *argv[] )
    struct fon_font *font;
    int i;
 
+#ifdef ENABLE_NLS
+   setlocale (LC_MESSAGES, "");
+   bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+   textdomain (PACKAGE);
+#endif
+
 /*
 ** determine infiles 
 */
@@ -51,38 +64,38 @@ int main( int argc, char *argv[] )
    }
    else
    {
-      puts( "\nUsage: rio_font_info file" );
+      fprintf(stderr, N_("\nUsage: rio_font_info file"));
       exit(0);
    }
 
    if ( ( fpin = fopen( infile, "rb" ) ) == 0 )
    {
-      printf( "font_info: could not open '%s' for reading\n", infile );
+      printf(_("font_info: could not open '%s' for reading\n"), infile );
       exit( 1 );
    }
 
    font = fon_load_font(infile);
 
-   printf("Number of fonts in file = %d\n", font->number_of_fonts);
+   printf(_("Number of fonts in file = %d\n"), font->number_of_fonts);
    for (i=0; i<font->number_of_fonts; i++) {
-	printf("Windows_version[%d] = %x\n", i, font->Header[i].Windows_version);
-	printf("File_size?[%d] = %x\n", i, font->Header[i].File_sizeH*65536+font->Header[i].File_sizeL);
-	printf("Copyright[%d] = %s\n", i, font->Header[i].Copyright);
-	printf("Type_of_font_file?[%d] = %x\n", i, font->Header[i].Type_of_font_file);
-	printf("Nominal_point_size[%d] = %x\n", i, font->Header[i].Nominal_point_size);
-	printf("Vertical_resolution[%d] = %x\n", i, font->Header[i].Vertical_resolution);
-	printf("Horizontal_resolution[%d] = %x\n", i, font->Header[i].Horizontal_resolution);
-	printf("Point_size[%d] = %x\n", i, font->Header[i].Point_size);
-	printf("Bytes_per_char_cell[%d] = %x\n", i, font->Header[i].Bytes_per_char_cell);
-	printf("Thirty?[%d] = %x\n", i, font->Header[i].Thirty);
-	printf("Avg_point_size[%d] = %x\n", i, font->Header[i].Avg_point_sizeH*256+font->Header[i].Avg_point_sizeL);
-	printf("Max_point_size[%d] = %x\n", i, font->Header[i].Max_point_sizeH*256+font->Header[i].Max_point_sizeL);
-	printf("Initial_char_code[%d] = %x\n", i, font->Header[i].Initial_char_code);
-	printf("Last_char_code?[%d] = %x\n", i, font->Header[i].Last_char_code);
-	printf("Default_char_code?[%d] = %x\n", i, font->Header[i].Default_char_code);
-	printf("Break_char_code?[%d] = %x\n", i, font->Header[i].Break_char_code);
-	printf("Total_number_of_chars[%d] = %x\n", i, font->Header[i].Total_number_of_chars);
-	printf("Offset_to_next_font[%d] = %x\n", i, font->Header[i].Offset_to_next_fontH*256+font->Header[i].Offset_to_next_fontL);
+	printf(_("Windows_version[%d] = %x\n"), i, font->Header[i].Windows_version);
+	printf(_("File_size?[%d] = %x\n"), i, font->Header[i].File_sizeH*65536+font->Header[i].File_sizeL);
+	printf(_("Copyright[%d] = %s\n"), i, font->Header[i].Copyright);
+	printf(_("Type_of_font_file?[%d] = %x\n"), i, font->Header[i].Type_of_font_file);
+	printf(_("Nominal_point_size[%d] = %x\n"), i, font->Header[i].Nominal_point_size);
+	printf(_("Vertical_resolution[%d] = %x\n"), i, font->Header[i].Vertical_resolution);
+	printf(_("Horizontal_resolution[%d] = %x\n"), i, font->Header[i].Horizontal_resolution);
+	printf(_("Point_size[%d] = %x\n"), i, font->Header[i].Point_size);
+	printf(_("Bytes_per_char_cell[%d] = %x\n"), i, font->Header[i].Bytes_per_char_cell);
+	printf(_("Thirty?[%d] = %x\n"), i, font->Header[i].Thirty);
+	printf(_("Avg_point_size[%d] = %x\n"), i, font->Header[i].Avg_point_sizeH*256+font->Header[i].Avg_point_sizeL);
+	printf(_("Max_point_size[%d] = %x\n"), i, font->Header[i].Max_point_sizeH*256+font->Header[i].Max_point_sizeL);
+	printf(_("Initial_char_code[%d] = %x\n"), i, font->Header[i].Initial_char_code);
+	printf(_("Last_char_code?[%d] = %x\n"), i, font->Header[i].Last_char_code);
+	printf(_("Default_char_code?[%d] = %x\n"), i, font->Header[i].Default_char_code);
+	printf(_("Break_char_code?[%d] = %x\n"), i, font->Header[i].Break_char_code);
+	printf(_("Total_number_of_chars[%d] = %x\n"), i, font->Header[i].Total_number_of_chars);
+	printf(_("Offset_to_next_font[%d] = %x\n"), i, font->Header[i].Offset_to_next_fontH*256+font->Header[i].Offset_to_next_fontL);
 	printf("\n");
     }
 
@@ -107,10 +120,10 @@ static char const *const option_help[] =
 "",
 "Miscellaneous options:",
 "",
-"  -v  --version     Output version info.",
-"  -h  --help        Output this help.",
+N_("  -v        --version          Output version info."),
+N_("  -h        --help             Output this help."),
 "",
-"Report bugs to <rio500-devel@lists.sourceforge.net>.",
+N_("Report bugs to <rio500-devel@lists.sourceforge.net>."),
 0
 };
 
@@ -129,19 +142,14 @@ get_some_switches (int argc, char *argv[])
            != -1) {
          switch (optc) {
             case 'v':
-                printf("\nrio_font_info -- version %s\n",VERSION);
+                printf(_("\nrio_font_info -- version %s\n"),VERSION);
                 exit(0);
                 break;
             case 'h':
-                puts("\nUsage: rio_font_info file");
+	    default:
+                puts(_("\nUsage: rio_font_info file"));
                 for (p=option_help;  *p ;  p++)
-                  fprintf (stderr, "%s\n", *p);
-                exit(0);
-                break;
-            default:
-                puts("\nUsage: rio_font_info file");
-                for (p=option_help;  *p ;  p++)
-                  fprintf (stderr, "%s\n", *p);
+                  fprintf (stderr, "%s\n", **p ? gettext(*p) : *p);
                 exit(0);
                 break;
 
