@@ -26,18 +26,29 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <string.h>
 
+#ifdef WITH_USBDEVFS
+#include <usb.h>
+#endif
+
+#include "config.h"
+#ifdef ENABLE_NLS
+#include <locale.h>
+#endif
 #include "librio500.h"
+#include "i18n.h"
 #include "getopt.h"
+
 void get_some_switches (int argc, char *argv[], int * automat, int *format_internal, int *format_external);
 void usage (char *progname);
 
 void
 usage (char *progname)
 {
-  printf ("\nusage: %s [OPTIONS] \n", progname);
+  printf (_("\nusage: %s [OPTIONS] \n"), progname);
   printf ("\n");
-  printf ("\n Formats the Rio flash memory, erasing all songs and folders\n");
+  printf (_("\n Formats the Rio flash memory, erasing all songs and folders\n"));
   printf("\n");
 return;
 }
@@ -49,16 +60,23 @@ main(int argc, char *argv[])
   int automatic = 0;
   int format_internal = 0;
   int format_external = 0;
-  int i;
 
 #ifndef WITH_USBDEVFS
   int rio_dev;
 #else
-  struct usbdevice *rio_dev;
-
-  rio_dev = malloc(sizeof(struct usbdevice));
+  usb_dev_handle *rio_dev;
 #endif
 
+#ifdef ENABLE_NLS
+  setlocale (LC_MESSAGES, "");
+  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  textdomain (PACKAGE);
+#endif
+
+/* #ifdef WITH_USBDEVFS
+  rio_dev = malloc(sizeof(usb_dev_handle));
+#endif */
+
   get_some_switches(argc,argv,&automatic,&format_internal,&format_external);
 
   /* if no switches set, default to formatting internal memory */
@@ -71,27 +89,27 @@ main(int argc, char *argv[])
       /* Issue a warning */
       printf ("\n\n");
       printf ("---------------------------------------------------------\n");
-      printf ("                  W A R N I N G\n");
+      printf (_("                  W A R N I N G\n"));
       printf ("---------------------------------------------------------\n");
       printf ("\n");
-      printf ("This command will erase ALL your folders and songs stored\n");
-      printf ("on your RIO 500's ");
+      printf (_("This command will erase ALL your folders and songs stored\n"));
+      printf (_("on your RIO 500's "));
 
       if (format_internal)
-        printf("internal ");
+        printf(_("internal "));
       if (format_internal && format_external)
-        printf("and ");
+        printf(_("and "));
       if (format_external)
-        printf("external ");
+        printf(_("external "));
 
-      printf ("memory.\n\nAnswer with yes if you want to continue? ");
+      printf (_("memory.\n\nAnswer with yes if you want to continue? "));
  
       scanf ("%s", answer);
 
-      if (strcmp (answer, "yes") != 0) {
-#ifdef WITH_USBDEVFS
+      if ((strcmp (answer, "yes") != 0) && (strcmp (answer, _("yes")) != 0))  {
+/* #ifdef WITH_USBDEVFS
         free(rio_dev);
-#endif
+#endif */
 	exit(0);
       }
     }
@@ -100,7 +118,7 @@ main(int argc, char *argv[])
   rio_dev = open (DEFAULT_DEV_PATH, O_RDWR);
   if (rio_dev == -1)
     {
-      perror ("open failed");
+      perror (_("open failed"));
       exit (-1);
     }
    /* Init communication with rio */
@@ -108,7 +126,7 @@ main(int argc, char *argv[])
 
 #else
    if(!(rio_dev = init_communication())) {
-     printf("init_communication() failed!\n");
+     printf(_("init_communication() failed!\n"));
      free(rio_dev);
      return -1;
    }
@@ -120,18 +138,18 @@ main(int argc, char *argv[])
 
    if (format_external && query_card_count(rio_dev) > 1)
    {
-     printf("Formatting external memory card...\n");
+     printf(_("Formatting external memory card...\n"));
      format_flash (rio_dev, 1);
-     printf("Done!\n");
+     printf(_("Done!\n"));
    }
    else if (!format_internal)
-     printf("Unable to find an external memory card to format.\n");
+     printf(_("Unable to find an external memory card to format.\n"));
 
    if (format_internal)
    {
-     printf("Formatting internal memory card...\n");
+     printf(_("Formatting internal memory card...\n"));
      format_flash (rio_dev, 0);
-     printf("Done!\n");
+     printf(_("Done!\n"));
    }
 
    /* Close device */
@@ -159,19 +177,19 @@ static struct option const longopts[] =
 
 static char const *const option_help[] =
 {
-"Input options:",
+N_("Input options:"),
 "",
-"  -a        --automatic        Format rio without prompting",
-"  -x        --external         Format only the external smartmedia card",
-"  -i        --internal         Format only the internal memory",
-"  -b        --both             Format internal memory and external smartmedia card",
+N_("  -a        --automatic        Format rio without prompting"),
+N_("  -x        --external         Format only the external smartmedia card"),
+N_("  -i        --internal         Format only the internal memory"),
+N_("  -b        --both             Format internal memory and external smartmedia card"),
 "",
-"Miscellaneous options:",
+N_("Miscellaneous options:"),
 "",
-"  -v  --version     Output version info.",
-"  -h  --help        Output this help.",
+N_("  -v        --version          Output version info."),
+N_("  -h        --help             Output this help."),
 "",
-"Report bugs to <rio500-devel@lists.sourceforge.net>.",
+N_("Report bugs to <rio500-devel@lists.sourceforge.net>."),
 0
 };
 
@@ -193,7 +211,7 @@ get_some_switches (int argc, char *argv[], int * automat, int *format_internal,
                 *automat = 1;
                 break;
             case 'v':
-                printf("\nrio_format -- version %s\n",VERSION);
+                printf(_("\nrio_format -- version %s\n"),VERSION);
                 exit(0);
                 break;
 	    case 'i':
@@ -207,15 +225,10 @@ get_some_switches (int argc, char *argv[], int * automat, int *format_internal,
 		*format_external=1;
 		break;
             case 'h':
+	    default:
                 usage(argv[0]);
                 for (p=option_help;  *p ;  p++)
-                  fprintf (stderr, "%s\n", *p);
-                exit(0);
-                break;
-            default:
-                usage(argv[0]);
-                for (p=option_help;  *p ;  p++)
-                  fprintf (stderr, "%s\n", *p);
+                  fprintf (stderr, "%s\n", **p ? gettext(*p) : *p);
                 exit(0);
                 break;
 
