@@ -29,6 +29,7 @@
 #include <errno.h>
 
 #include "librio500.h"
+#include "i18n.h"
 
 
 #define FOLDER_BLOCK_SIZE           0x4000
@@ -47,29 +48,29 @@ void signal_handler (int signal);
 #ifndef WITH_USBDEVFS
 void read_file (int rio_dev, unsigned long size, char *filename, int card);
 #else
-void read_file (struct usbdevice *rio_dev, unsigned long size, char *filename, int card);
+void read_file (struct usb_dev_handle *rio_dev, unsigned long size, char *filename, int card);
 #endif
 
 
 void
 usage (char *progname)
 {
-  printf ("\nusage: %s <song_num> <folder_num> <card_num>\n", progname);
-  printf ("\n <file> is the name of the file whose content");
-  printf ("\n we want to upload.");
-  printf ("\n <folder_num> is the index to the folder where it will be put.\n");
-  printf (" <card_num> is the index of the memory card to use\n");
-  printf (" card_num=0=internal memory, card_num=1=external memory card\n");
+  printf (_("\nusage: %s <song_num> <folder_num> <card_num>\n"), progname);
+  printf (_("\n <song_num> is the index of the song we want to"));
+  printf (_("\n download from rio500 to hard drive."));
+  printf (_("\n <folder_num> is the index to the folder where it will be put.\n"));
+  printf (_(" <card_num> is the index of the memory card to use\n\n"));
+  printf (_(" card_num=0=internal memory, card_num=1=external memory card\n"));
   return;
 }
 
+int
 main(int argc, char *argv[])
 {
-  int               old_offset, i, length;
-  int               folder_block_offset, song_block_offset;
-  int               folder_num, song_num, font_number;
+  int               old_offset;
+  int               folder_block_offset;
+  int               folder_num, song_num;
   GList            *folders, *songs;
-  folder_entry     *folder;
   song_entry       *song;
   folder_entry     *f_entry;
   int		   card;
@@ -77,11 +78,19 @@ main(int argc, char *argv[])
 #ifndef WITH_USBDEVFS
   int               rio_dev;
 #else
-  struct usbdevice *rio_dev;
-
-  rio_dev = malloc(sizeof(struct usbdevice));
+  struct usb_dev_handle *rio_dev;
 #endif
 
+#ifdef ENABLE_NLS
+  setlocale (LC_MESSAGES, "");
+  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  textdomain (PACKAGE);
+#endif
+
+/* #ifdef WITH_USBDEVFS
+  rio_dev = malloc(sizeof(struct usbdevice));
+#endif */
+
   /* Setup signal handler */
   signal (SIGINT , signal_handler);
   signal (SIGQUIT, signal_handler);
@@ -113,7 +122,7 @@ main(int argc, char *argv[])
   rio_dev = open (DEFAULT_DEV_PATH, O_RDWR);
   if (rio_dev < 0)
     {
-      perror ("\nVerify that your Rio is connected and powered up.\n\n");
+      perror (_("\nVerify that the rio module is loaded and your Rio is\nconnected and powered up "));
       exit (-1);
     }
 
@@ -121,8 +130,8 @@ main(int argc, char *argv[])
    init_communication (rio_dev);
 #else
    if(!(rio_dev = init_communication())) {
-     printf("init_communication() failed!\n");
-     free(rio_dev);
+     printf(_("init_communication() failed!\n"));
+     //free(rio_dev);
      return -1;
    }
 #endif
@@ -134,6 +143,7 @@ main(int argc, char *argv[])
    /* mem = get_mem_status (rio_dev); */
 
    /* Read folder & song block */
+   send_command(rio_dev, 0x42, 0, 0);
    folders = read_folder_entries (rio_dev,card);
    if ( folder_num > g_list_length (folders)-1 )
      folder_num = 0;
@@ -141,7 +151,7 @@ main(int argc, char *argv[])
 
    if (song_num > g_list_length (songs)-1)
    {
-     printf ("Incorrect song_num parameter!\n");
+     printf (_("Incorrect song_num parameter!\n"));
      goto end;
    }
 
@@ -151,7 +161,7 @@ main(int argc, char *argv[])
  
    if (f_entry == NULL || song == NULL)
    {
-     printf ("Incorrect song_num or folder_num parameter!\n");
+     printf (_("Incorrect song_num or folder_num parameter!\n"));
      goto end;
    }
 
@@ -201,16 +211,14 @@ void
 #ifndef WITH_USBDEVFS
 read_file (int rio_dev, unsigned long size, char *filename, int card)
 #else
-read_file (struct usbdevice *rio_dev, unsigned long size, char *filename, int card)
+read_file (struct usb_dev_handle *rio_dev, unsigned long size, char *filename, int card)
 #endif
 {
   int output_file;
-  struct stat file_stat;
-  int  i, j, this_read, block_length;
+  int  i, j, this_read;
   int  total, count, num_blocks, remainder, blocks_left;
-  BYTE *block, *p, address[2];
-  unsigned short offset;
-  int num_chunks, song_location;
+  BYTE *block;
+  int num_chunks;
 
   block = (char *)malloc (0x80000);
 
@@ -219,7 +227,7 @@ read_file (struct usbdevice *rio_dev, unsigned long size, char *filename, int ca
   if (output_file == -1)
     return;
 
-  printf ("Reading file: %s  ", filename);
+  printf (_("Reading file: %s  "), filename);
   fflush (stdout);
 
   /* Read 0x4000 bytes first */
@@ -292,7 +300,7 @@ read_file (struct usbdevice *rio_dev, unsigned long size, char *filename, int ca
     remainder -= this_read;
   }
 
-  printf (" (done. Transfered %d bytes.)\n", total);
+  printf (_(" (done. Transfered %d bytes.)\n"), total);
   fflush (stdout);
 
   return;
@@ -304,9 +312,9 @@ void signal_handler (int signal)
   {
     case 1:
     case 2:
-      printf ("Cannot interrupt transfer! Please wait for transfer to complete ...\n");
+      printf (_("Cannot interrupt transfer! Please wait for transfer to complete ...\n"));
       break;
     default:
-      printf ("Signal [%d] trapped! Ignoring ... \n", signal);
+      printf (_("Signal [%d] trapped! Ignoring ... \n"), signal);
   }
 }
